#
# spec file for package perl-Data-Clone
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Data-Clone
Name:           perl-Data-Clone
Version:        0.6.0
Release:        2.7
%define cpan_version 0.006
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Polymorphic data cloning
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/I/IS/ISHIGAKI/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        perl-Data-Clone-rpmlintrc
Source2:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Devel::PPPort) >= 3.19
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.59
BuildRequires:  perl(ExtUtils::ParseXS) >= 3.18
BuildRequires:  perl(Module::Build) >= 0.4005
BuildRequires:  perl(Module::Build::XSUtil) >= 0.03
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Requires) >= 0.03
BuildRequires:  perl(parent)
Requires:       perl(parent)
Provides:       perl(Data::Clone) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
'Data::Clone' does data cloning, i.e. copies things recursively. This is
smart so that it works with not only non-blessed references, but also with
blessed references (i.e. objects). When 'clone()' finds an object, it calls
a 'clone' method of the object if the object has a 'clone', otherwise it
makes a surface copy of the object. That is, this module does polymorphic
data cloning.

Although there are several modules on CPAN which can clone data, this
module has a different cloning policy from almost all of them. See Cloning
policy and Comparison to other cloning modules for details.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Build.PL --installdirs=vendor optimize="%{optflags}"
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes example README.md
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Thu Nov 30 2023 Tina Müller <tina.mueller@suse.com>
- Remove perl-Data-Clone-perl-5.38.patch (fixed upstream)
* Sun Nov 26 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.006
  see /usr/share/doc/packages/perl-Data-Clone/Changes
  0.006 2023-11-25T05:46:27Z
  - No code changes
  - Migrate from Module::Install to Minilla
  0.005 2023-11-21
  - Fix against Perl 5.38 (#3, by demerphq)
* Tue Aug  8 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add perl-Data-Clone-perl-5.38.patch: Fix build using Perl 5.38.
* Tue Oct  3 2017 coolo@suse.com
- patch the Makefile to build with perl 5.26
* Tue Jul 22 2014 coolo@suse.com
- updated to 0.004
  - Fix against Perl 5.19 (#1, by tomhukins)
* Fri Sep 30 2011 pascal.bleser@opensuse.org
- skip tests on < 11.3, Test::More too old there
* Fri Sep 30 2011 pascal.bleser@opensuse.org
- initial version (0.003)
